@@ -1576,21 +1576,22 @@ namespace highlight
 
 	bool CodeGenerator::printExternalStyle ( const string &outFile )
 	{
-		if ( !includeStyleDef && currentSyntax->highlightingEnabled() )
+		if ( !includeStyleDef /*&& currentSyntax->highlightingEnabled()*/ )
 		{
 			ostream *cssOutFile = ( outFile.empty() ? &cout :new ofstream ( outFile.c_str() ) );
 			if ( !cssOutFile->fail() )
 			{
 				*cssOutFile << styleCommentOpen
-				  <<" Style definition file generated by highlight "
-				  << HIGHLIGHT_VERSION << ", " << HIGHLIGHT_URL
-				  << " " << styleCommentClose << "\n";
+					    <<" Style definition file generated by highlight "
+					    << HIGHLIGHT_VERSION << ", " << HIGHLIGHT_URL
+					    << " " << styleCommentClose << "\n";
 
 				*cssOutFile << "\n" << styleCommentOpen
-				  << " Highlighting theme: "<<docStyle.getDescription()<<" "
-				  << styleCommentClose << "\n\n"
-				  << getStyleDefinition()
-				  << "\n";
+						    << " Highlighting theme: "
+						    << docStyle.getDescription() <<" "
+						    << styleCommentClose << "\n\n"
+						    << getStyleDefinition()
+						    << "\n";
 				*cssOutFile << readUserStyleDef();
 				if ( !outFile.empty() ) delete cssOutFile;
 			}
